utils

package
v0.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2026 License: BSD-2-Clause Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckForUpdates added in v0.6.2

func CheckForUpdates(rootCmd *cobra.Command) error

CheckForUpdates checks if a new version of your application is pushed, and notifies the user, if DisableUpdateChecking is true.

func GetRepoPath added in v0.7.0

func GetRepoPath() string

func IsUpdateAvailable added in v0.7.0

func IsUpdateAvailable(currentVersion string) (bool, string, error)

IsUpdateAvailable checks if there is a newer version available on GitHub. It returns true if an update is available, the latest tag name, and any error encountered.

func RemoveCodeBlock

func RemoveCodeBlock(input string) string

RemoveCodeBlock removes code block tags from a string. If no code block tags are found, it returns the original string.

Types

This section is empty.

Jump to