Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckForUpdates ¶ added in v0.6.2
CheckForUpdates checks if a new version of your application is pushed, and notifies the user, if DisableUpdateChecking is true.
func GetRepoPath ¶ added in v0.7.0
func GetRepoPath() string
func IsUpdateAvailable ¶ added in v0.7.0
IsUpdateAvailable checks if there is a newer version available on GitHub. It returns true if an update is available, the latest tag name, and any error encountered.
func RemoveCodeBlock ¶
RemoveCodeBlock removes code block tags from a string. If no code block tags are found, it returns the original string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.